unit MainForm;

interface

uses
  SysUtils, Classes, 
  {$IFDEF LINUX}
  QDialogs, QMenus, QTypes, QStdCtrls, QComCtrls, QGrids, QDBGrids, QControls,
  QExtCtrls, QDBCtrls, QForms,
  {$ELSE}
  Windows, Messages, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Mask, DBCtrls, Grids, DBGrids, ExtCtrls,
  DBCGrids, Menus, ComCtrls, ActnList,
  {$ENDIF}
  DB, TdbTypes, TdbDataSet, TdbBatchMove, TdbLicense;

type
  TTdbSampleForm = class(TForm)
    TdbDatabase: TTdbDatabase;
    DBNavigator1: TDBNavigator;
    DepartmentDBGrid: TDBGrid;
    DepartmentTable: TTdbTable;
    DepartmentDataSource: TDataSource;
    DepartmentTableName: TStringField;
    DepartmentTableHomepage: TStringField;
    EmployeeDataSource: TDataSource;
    EmployeeTable: TTdbTable;
    DepartmentTableRecordId: TIntegerField;
    DBNavigator2: TDBNavigator;
    MainMenu1: TMainMenu;
    FileMItem: TMenuItem;
    QuitMItem: TMenuItem;
    EditMItem: TMenuItem;
    PreviousMItem: TMenuItem;
    NextMItem: TMenuItem;
    SearchMItem: TMenuItem;
    LocateMItem: TMenuItem;
    SetFilter1: TMenuItem;
    Export1: TMenuItem;
    TextFormat1: TMenuItem;
    dbaseformatex: TMenuItem;
    xmlformat1: TMenuItem;
    HelpMitem: TMenuItem;
    AboutMItem: TMenuItem;
    DepartmentSortingBox: TComboBox;
    EmployeeSortingBox: TComboBox;
    EmployeeDBGrid: TDBGrid;
    EmployeeTableName: TStringField;
    EmployeeTableFirstName: TStringField;
    EmployeeTableEMail: TStringField;
    EmployeeTableDepartment: TStringField;
    EmployeeTableSalary: TFloatField;
    EmployeeTableRecordId: TIntegerField;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    StatusBar1: TStatusBar;
    MasterCheckBox: TCheckBox;
    EmployeeExport: TTdbBatchMove;
    ExportTable: TTdbTable;
    FilterCheckBox: TCheckBox;

    procedure DepartmentSortingBoxChange(Sender: TObject);
    procedure EmployeeSortingBoxChange(Sender: TObject);
    procedure MasterCheckBoxClick(Sender: TObject);
    procedure TextFormat1Click(Sender: TObject);
    procedure dbaseformatexClick(Sender: TObject);
    procedure xmlformat1Click(Sender: TObject);
    procedure LocateMItemClick(Sender: TObject);
    procedure FilterCheckBoxClick(Sender: TObject);
    procedure SetFilter1Click(Sender: TObject);
    procedure AboutMItemClick(Sender: TObject);
    procedure PreviousMItemClick(Sender: TObject);
    procedure NextMItemClick(Sender: TObject);
    procedure QuitMItemClick(Sender: TObject);
    procedure EmployeeDBGridTitleClick(Column: TColumn);
    procedure FormCreate(Sender: TObject);
  private
    procedure SetFilter;
    procedure StartExport;
  public
  end;

var
  TdbSampleForm: TTdbSampleForm;

implementation

{$IFDEF LINUX}
	{$R *.xfm}
{$ELSE}
	{$R *.dfm}
{$ENDIF}

uses
  about, FilterUnit, LocateUnit;

procedure TTdbSampleForm.AboutMItemClick(Sender: TObject);
var
 AboutFrm: TAboutFrm;
begin
  AboutFrm:= TAboutFrm.Create(self);
  AboutFrm.ShowModal;
  AboutFrm.Free;

end;


procedure TTdbSampleForm.dbaseformatexClick(Sender: TObject);
begin
  EmployeeExport.Filename := 'EmployeeExport.dbf';
  EmployeeExport.FileType := tffdbase;
  StartExport;
end;


procedure TTdbSampleForm.TextFormat1Click(Sender: TObject);
begin
  EmployeeExport.Filename := 'EmployeeExport.txt';
  EmployeeExport.FileType := tffSDF;
  EmployeeExport.Quote := '"';
  EmployeeExport.Separator := ';';
  StartExport;
end;


procedure TTdbSampleForm.DepartmentSortingBoxChange(Sender: TObject);
begin
  if DepartmentSortingBox.ItemIndex > 0 then
    DepartmentTable.IndexName := DepartmentTable.IndexDefs[DepartmentSortingBox.ItemIndex-1].Name
  else
    DepartmentTable.IndexName := '';
end;


procedure TTdbSampleForm.EmployeeDBGridTitleClick(Column: TColumn);
var
  LocateForm: TLocateForm;
  SearchStr: String;
begin
  LocateForm:= TLocateForm.Create(Self);
  LocateForm.Label1.Caption := Column.FieldName;
  if LocateForm.ShowModal= mrOk then begin
    SearchStr := LocateForm.Edit1.Text;
  end;
  LocateForm.Free;
  if not EmployeeTable.Locate(Column.FieldName, SearchStr, [loCaseInsensitive, loPartialKey]) then
    MessageDlg('No matching record',  mtInformation, [mbOk], 0);
end;


procedure TTdbSampleForm.EmployeeSortingBoxChange(Sender: TObject);
begin
  if EmployeeSortingBox.ItemIndex > 0 then
    EmployeeTable.IndexName := EmployeeTable.IndexDefs[EmployeeSortingBox.ItemIndex -1].Name
  else
    EmployeeTable.IndexName := ''; 
end;


procedure TTdbSampleForm.FilterCheckBoxClick(Sender: TObject);
begin
  if FilterCheckBox.Checked then begin
    SetFilter;
  end else begin
    DepartmentTable.Filtered := False;
  end;
end;


procedure TTdbSampleForm.FormCreate(Sender: TObject);
var
  i: Integer;
begin
  DepartmentTable.Open;
	EmployeeTable.Open;
  DepartmentSortingBox.Items.Clear;
  DepartmentSortingBox.Items.Add('None');
  // Indexdefinition
  for i := 1 to DepartmentTable.IndexDefs.Count do
    DepartmentSortingBox.Items.Add(DepartmentTable.IndexDefs[i-1].Fields);
  DepartmentSortingBox.ItemIndex := 0;
  EmployeeSortingBox.Items.Clear;
  EmployeeSortingBox.Items.Add('None');
  for i := 1 to EmployeeTable.IndexDefs.Count do
    EmployeeSortingBox.Items.Add(EmployeeTable.IndexDefs[i-1].Fields);
  EmployeeSortingBox.ItemIndex := 0;
end;


procedure TTdbSampleForm.LocateMItemClick(Sender: TObject);
var
  LocateForm: TLocateForm;
  Department: String;
begin
  LocateForm:= TLocateForm.Create(Self);
  if LocateForm.ShowModal= mrOk then begin
    Department := LocateForm.Edit1.Text;
    DepartmentTable.Filtered := False;
  end;
  if Assigned(LocateForm) then LocateForm.Free;
  if not DepartmentTable.Locate('Name', Department, [loCaseInsensitive, loPartialKey]) then
  MessageDlg('No matching record',  mtInformation, [mbOk], 0);
end;


procedure TTdbSampleForm.MasterCheckBoxClick(Sender: TObject);
begin
  if MasterCheckBox.Checked then
    EmployeeTable.MasterSource := DepartmentDataSource
  else
    EmployeeTable.MasterSource := nil;
  DepartmentTable.Refresh;

  if EmployeeSortingBox.ItemIndex >= 0 then
    EmployeeTable.IndexName := EmployeeTable.IndexDefs[EmployeeSortingBox.ItemIndex].Name;
  EmployeeTable.Refresh;
end;


procedure TTdbSampleForm.NextMItemClick(Sender: TObject);
begin
  DepartmentTable.Next;
end;


procedure TTdbSampleForm.PreviousMItemClick(Sender: TObject);
begin
  DepartmentTable.Prior;
end;


procedure TTdbSampleForm.QuitMItemClick(Sender: TObject);
begin
  Close;
end;


procedure TTdbSampleForm.SetFilter;
var
  FilterForm: TFilterForm;
begin
  FilterForm:= TFilterForm.Create(Self);
  if FilterForm.ShowModal= mrOk then
  begin
    DepartmentTable.Filter := FilterForm.Edit1.Text;
    try
     DepartmentTable.Filtered := True;
    except
      MessageDlg('No matching record',  mtInformation, [mbOk], 0);
      DepartmentTable.Filtered := False;
      FilterCheckBox.checked := False;
    end;
  end else DepartmentTable.Filtered := False;
  FilterForm.Free;
end;


procedure TTdbSampleForm.SetFilter1Click(Sender: TObject);
begin
  SetFilter;
end;


procedure TTdbSampleForm.StartExport;
begin
  // temporary closing all tables and setting
  // employeetable as exporttable
  DepartmentTable.Active := false;
  EmployeeTable.Active := false;
  ExportTable.Active := true;

  EmployeeExport.TdbDataSet := ExportTable;
  EmployeeExport.Execute;
  // reopening tables
  ExportTable.Active := False;
  DepartmentTable.Active := true;
  EmployeeTable.Active := true;
end;


procedure TTdbSampleForm.xmlformat1Click(Sender: TObject);
begin
  EmployeeExport.Filename := 'EmployeeExport.xml';
  EmployeeExport.FileType := tffMyBase;
  StartExport;
end;


end.
