unit FTDemoFrm;

interface

uses
  SysUtils, Classes, DB,
  {$ifdef LINUX}
  QGraphics, QControls, QForms, QDialogs,
  QStdCtrls, QDBCtrls, QGrids, QDBGrids, QExtCtrls,
  {$else}
  Windows, Messages, Graphics, Controls, Forms, Dialogs,
  StdCtrls, DBCtrls, Grids, DBGrids, ExtCtrls,
  {$endif}
  TdbDataSet, TdbLicense;

type
  TFTDemoForm = class(TForm)
    IndexTable: TTdbTable;
    TdbDatabase: TTdbDatabase;
    FilesTable: TTdbTable;
    Splitter1: TSplitter;
    Panel1: TPanel;
    FilesDataSource: TDataSource;
    DirectoryEdit: TEdit;
    DirectoryBtn: TButton;
    DBNavigator1: TDBNavigator;
    DBGrid1: TDBGrid;
    ScanBtn: TButton;
    SubDirsCheckBox: TCheckBox;
    ExtensionsLabel: TLabel;
    ExtsMemo: TMemo;
    FindLabel: TLabel;
    FilterEdit: TEdit;
    FindBtn: TButton;
    ShowAllBtn: TButton;
    ContentDBMemo: TDBMemo;
    procedure DirectoryBtnClick(Sender: TObject);
    procedure ScanBtnClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure EditorBtnClick(Sender: TObject);
    procedure FindBtnClick(Sender: TObject);
    procedure ShowAllBtnClick(Sender: TObject);
  private
  	procedure ScanDirectory(Directory: string; SubDirs: Boolean);
  public
    { Public declarations }
  end;

var
  FTDemoForm: TFTDemoForm;

implementation

{$ifdef LINUX}
{$R *.xfm}
{$else}
{$R *.dfm}
uses ShellApi, FileCtrl;
{$endif}


procedure TFTDemoForm.DirectoryBtnClick(Sender: TObject);
var
  {$ifdef VER145}
  LDirectory: WideString;
  {$else}
	LDirectory: string;
  {$endif}
begin
	if SelectDirectory('Select Directory to Scan', '', LDirectory) then
  	DirectoryEdit.Text := LDirectory;
end;


procedure TFTDemoForm.EditorBtnClick(Sender: TObject);
begin
  {$ifndef LINUX}
	ShellExecute(Handle, 'open', PChar(FilesTable.FieldByName('FileName').AsString), '', '', SW_SHOW);
  {$endif}
end;


procedure TFTDemoForm.FindBtnClick(Sender: TObject);
begin
	FilesTable.Filtered := False;
  FilesTable.WordFilter := FilterEdit.Text;
  FilesTable.Filtered := True;
end;


procedure TFTDemoForm.FormCreate(Sender: TObject);
begin
	TdbDatabase.Connected;
  IndexTable.Open;
  FilesTable.Open;
  DirectoryEdit.Text := GetCurrentDir;
end;


procedure TFTDemoForm.ScanBtnClick(Sender: TObject);
begin
	FilesTable.EmptyTable;
  IndexTable.EmptyTable;
	ScanDirectory(DirectoryEdit.Text, SubDirsCheckBox.Checked);
  FilesTable.UpdateFulltextIndex('Filename,Content', 'Keywords', 'counter.txt', 1000);
end;


procedure TFTDemoForm.ScanDirectory(Directory: string; SubDirs: Boolean);
var
	ScanPath: string;
  ScanMask: string;
	SearchRec: TSearchRec;
  SearchRes: Integer;
  sl: TStringList;
begin
	{$ifdef LINUX}
  ScanMask := '*';
  {$else}
  ScanMask := '*.*';
  {$endif}
	sl := TstringList.Create;
	//ScanPath := IncludeTrailingPathDelimiter(Directory);
  ScanPath := Directory;
	SearchRes := FindFirst(ScanPath + ScanMask, faAnyFile, SearchRec);
  while SearchRes = 0 do begin
  	if SearchRec.Attr and faDirectory > 0 then begin
    	if SubDirs and (SearchRec.Name <> '.') and (SearchRec.Name <> '..') then
				ScanDirectory(ScanPath + SearchRec.Name, SubDirs);
    end else if Pos(ExtractFileExt(SearchRec.Name), ExtsMemo.Text) > 0 then
		begin
    	sl.Clear;
      sl.LoadFromFile(ScanPath + SearchRec.Name);
    	FilesTable.Append;
      FilesTable.FieldByName('FileName').AsString := ScanPath + SearchRec.Name;
      FilesTable.FieldByname('Content').AsString := sl.Text;
			FilesTable.FieldByname('Date').AsDateTime := FileDateToDateTime(SearchRec.Time);
      FilesTable.Post;
    end;
  	SearchRes := FindNext(SearchRec);
    Application.ProcessMessages;
  end;
  SysUtils.FindClose(SearchRec);
  sl.Free;
end;


procedure TFTDemoForm.ShowAllBtnClick(Sender: TObject);
begin
	FilesTable.Filtered := False;
  FilesTable.Filter := '';
end;

end.


 